==> mopidy-1.1.1-1-any.pkg.tar.xz: usr/lib/python2.7/site-packages/mopidy/listener.py <==
from __future__ import absolute_import, unicode_literals

import logging

import pykka

logger = logging.getLogger(__name__)


def send_async(cls, event, **kwargs):
    # This file is imported by mopidy.backends, which again is imported by all
    # backend extensions. By importing modules that are not easily installable
    # close to their use, we make some extensions able to run their tests in a
    # virtualenv with global site-packages disabled.
    import gobject

    gobject.idle_add(lambda: send(cls, event, **kwargs))


def send(cls, event, **kwargs):
    listeners = pykka.ActorRegistry.get_by_class(cls)
    logger.debug('Sending %s to %s: %s', event, cls.__name__, kwargs)
    for listener in listeners:
        # Save time by calling methods on Pykka actor without creating a
        # throwaway actor proxy.
        #
        # Because we use `.tell()` there is no return channel for any errors,
        # so Pykka logs them immediately. The alternative would be to use
        # `.ask()` and `.get()` the returned futures to block for the listeners
        # to react and return their exceptions to us. Since emitting events in
        # practise is making calls upwards in the stack, blocking here would
        # quickly deadlock.
        listener.tell({
            'command': 'pykka_call',
            'attr_path': ('on_event',),
            'args': (event,),
            'kwargs': kwargs,
        })


class Listener(object):

    def on_event(self, event, **kwargs):
        """
        Called on all events.

        *MAY* be implemented by actor. By default, this method forwards the
        event to the specific event methods.

        :param event: the event name
        :type event: string
        :param kwargs: any other arguments to the specific event handlers
        """
        getattr(self, event)(**kwargs)

==> mopidy-1.1.2-1-any.pkg.tar.xz: usr/lib/python2.7/site-packages/mopidy/listener.py <==
from __future__ import absolute_import, unicode_literals

import logging

import pykka

logger = logging.getLogger(__name__)


def send_async(cls, event, **kwargs):
    # This file is imported by mopidy.backends, which again is imported by all
    # backend extensions. By importing modules that are not easily installable
    # close to their use, we make some extensions able to run their tests in a
    # virtualenv with global site-packages disabled.
    import gobject

    gobject.idle_add(lambda: send(cls, event, **kwargs))


def send(cls, event, **kwargs):
    listeners = pykka.ActorRegistry.get_by_class(cls)
    logger.debug('Sending %s to %s: %s', event, cls.__name__, kwargs)
    for listener in listeners:
        # Save time by calling methods on Pykka actor without creating a
        # throwaway actor proxy.
        #
        # Because we use `.tell()` there is no return channel for any errors,
        # so Pykka logs them immediately. The alternative would be to use
        # `.ask()` and `.get()` the returned futures to block for the listeners
        # to react and return their exceptions to us. Since emitting events in
        # practise is making calls upwards in the stack, blocking here would
        # quickly deadlock.
        listener.tell({
            'command': 'pykka_call',
            'attr_path': ('on_event',),
            'args': (event,),
            'kwargs': kwargs,
        })


class Listener(object):

    def on_event(self, event, **kwargs):
        """
        Called on all events.

        *MAY* be implemented by actor. By default, this method forwards the
        event to the specific event methods.

        :param event: the event name
        :type event: string
        :param kwargs: any other arguments to the specific event handlers
        """
        try:
            getattr(self, event)(**kwargs)
        except Exception:
            # Ensure we don't crash the actor due to "bad" events.
            logger.exception('Triggering event failed: %s', event)
